Ext.namespace('Configurator');

Configurator.ActionPanel = function(config)
{
    Configurator.ActionPanel.superclass.constructor.call(this, config);
};

Configurator.deviceStore = new Ext.data.Store(
{
    proxy: new Ext.data.HttpProxy(
    {
        url: '/json/apartment/getDevices',
        method: 'GET'
    }),
    reader: new Ext.data.JsonReader(
    {
        root: 'result',
        fields: [
        {
            name: 'id'
        }, 
        {
            name: 'name'
        }]
    })
});
Configurator.deviceStore.on('load', function(store, record, operation)
{
    store.each(function(oRecord)
    {
        oRecord.set('supername', oRecord.data['name'] + " (" + oRecord.data['id'] + ")");
    });
    store.commitChanges();
});

Configurator.zoneStore = new Ext.data.Store(
{
    proxy: new Ext.data.HttpProxy(
    {
        url: '/json/property/query?query=/apartment/zones/*(ZoneID,name)',
        method: 'GET'
    }),
    reader: new Ext.data.JsonReader(
    {
        root: 'result.zones',
        fields: [
        {
            name: 'ZoneID'
        }, 
        {
            name: 'name'
        }]
    })
});

Ext.extend(Configurator.ActionPanel, Ext.form.FieldSet, 
{
    setMyTitle: function(oActionSet)
    {
        var text = "???";
        if (oActionSet.rb1.checked) 
        {
            text = "" + oActionSet.cbZoneSelector.getRawValue() + " / " + oActionSet.cbGroupSelector.getRawValue();
        }
        if (oActionSet.rb2.checked) 
        {
            text = "" + oActionSet.cbDeviceSelector.getRawValue();
        }
        
        if (oActionSet.rbAction1.checked) 
        {
            text = "Szene " + oActionSet.cbSceneSelector.getRawValue() + " in " + text;
        }
        if (oActionSet.rbAction2.checked) 
        {
            text = "Ausgang " + oActionSet.outputValue.getValue() + "% fuer " + text;
        }
        if (oActionSet.rbAction3.checked) 
        {
            text = text + " blinkt";
        }
        
        if (oActionSet.rb3.checked) 
        {
            text = "Event " + oActionSet.txtHLE.getValue() + " ausloesen";
        }
        
        oActionSet.setTitle(text);
    },
    removeSubAction: function(panel, masterPanel)
    {
        if (masterPanel.actionsSets.length == 1) 
            return;
        for (var i = 0; i < masterPanel.actionsSets.length; i++) 
        {
            if (panel == masterPanel.actionsSets[i]) 
                masterPanel.actionsSets.splice(i, 1);
        }
        masterPanel.remove(panel);
        masterPanel.doLayout();
    },
    addSubAction: function()
    {
        var masterPanel = this;
        var iIndex = this.actionsSets.length;
        this.actionsSets[iIndex] = new Ext.form.FieldSet(
        {
            title: "????",
            collapsible: true
        });
        var oActionSet = this.actionsSets[iIndex];
        oActionSet.masterPanel = this;
        
        oActionSet.groupName = new Ext.data.Store(
        {
            proxy: new Ext.data.HttpProxy(
            {
                url: '/json/property/query?query=/apartment/zones/zone0/groups/*(group,name)',
                method: 'GET'
            }),
            reader: new Ext.data.JsonReader(
            {
                root: 'result.groups',
                fields: [
                {
                    name: 'group'
                }, 
                {
                    name: 'name'
                }]
            })
        });
        oActionSet.sceneStore = new Ext.data.Store(
        {
            proxy: new Ext.data.HttpProxy(
            {
                url: '/json/property/query?query=/apartment/zones/zone0/groups/group0/scenes/*(scene,name)',
                method: 'GET'
            }),
            reader: new Ext.data.JsonReader(
            {
                root: 'result.scenes',
                fields: [
                {
                    name: 'scene'
                }, 
                {
                    name: 'name'
                }]
            })
        });
        
        
        this.add(oActionSet);
        oActionSet.fieldSetTarget = new Ext.Panel(
        {
            layout: 'table',
            title: "Ziel",
            layoutConfig: 
            {
                columns: 3,
                tableAttrs: 
                {
                    style: 
                    {
                        margin: 3
                    }
                }
            }
        });
        oActionSet.add(oActionSet.fieldSetTarget);
        oActionSet.fieldSetAction = new Ext.Panel(
        {
            layout: 'table',
            title: "Aktion",
            layoutConfig: 
            {
                columns: 4,
                tableAttrs: 
                {
                    style: 
                    {
                        margin: 3,
                        width: "100%"
                    }
                },
                width: "100%"
            }
        });
        oActionSet.add(oActionSet.fieldSetAction);
        
        // testbutton einfuehren !
        
        oActionSet.rb3 = new Ext.form.Radio(
        {
            name: 'typeSelector_' + this.name + iIndex
        });
        oActionSet.fieldSetTarget.add(oActionSet.rb3);
        
        oActionSet.txtHLE = new Ext.form.TextField(
        {
            colspan: 2,
            emptyText: "Highlevelevent",
            width: "100%",
            disabled: true
        });
        oActionSet.fieldSetTarget.add(oActionSet.txtHLE);
        
        oActionSet.rb1 = new Ext.form.Radio(
        {
            name: 'typeSelector_' + this.name + iIndex,
            checked: true
        });
        oActionSet.fieldSetTarget.add(oActionSet.rb1);
        
        oActionSet.cbZoneSelector = new Ext.form.ComboBox(
        {
            name: 'zoneID',
            emptyText: "Zone",
            boxMinWidth: 165,
            width: 165,
            store: Configurator.zoneStore,
            valueField: 'ZoneID',
            displayField: 'name',
            triggerAction: 'all',
            selectOnFocus: true,
            editable: false
        });
        oActionSet.fieldSetTarget.add(oActionSet.cbZoneSelector);
        oActionSet.cbZoneSelector.myParent = oActionSet;
        
        oActionSet.cbGroupSelector = new Ext.form.ComboBox(
        {
            name: 'groupID',
            emptyText: "Gruppe",
            boxMinWidth: 165,
            width: 165,
            store: oActionSet.groupName,
            valueField: 'group',
            displayField: 'name',
            triggerAction: 'all',
            selectOnFocus: true,
            editable: false,
            disabled: true
        });
        oActionSet.fieldSetTarget.add(oActionSet.cbGroupSelector);
        oActionSet.cbGroupSelector.myParent = oActionSet;
        oActionSet.rb2 = new Ext.form.Radio(
        {
            name: 'typeSelector_' + this.name + iIndex
        });
        oActionSet.fieldSetTarget.add(oActionSet.rb2);
        
        oActionSet.cbDeviceSelector = new Ext.form.ComboBox(
        {
            colspan: 2,
            name: "deviceID",
            emptyText: "deviceDSID",
            boxMinWidth: 330,
            width: 330,
            disabled: true,
            store: Configurator.deviceStore,
            valueField: 'id',
            displayField: 'supername',
            triggerAction: 'all',
            selectOnFocus: true,
            editable: false
        });
        oActionSet.fieldSetTarget.add(oActionSet.cbDeviceSelector);
        
        oActionSet.formatingFormPanel = new Ext.Panel(
        {
            layout: "form",
            rowspan: 3,
            defaults: 
            {
                hideLabel: true
            },
            width: 120
        });
        oActionSet.fieldSetAction.add(oActionSet.formatingFormPanel);
        
        oActionSet.rbAction1 = new Ext.form.Radio(
        {
            name: 'actionSelector_' + this.name + iIndex,
            boxLabel: 'Szenenaufruf',
            width: 130
        });
        oActionSet.formatingFormPanel.add(oActionSet.rbAction1);
        
        oActionSet.cbSceneSelector = new Ext.form.ComboBox(
        {
            name: "scene",
            emptyText: "Szene auswaehlen",
            disabled: true,
            colspan: 3,
            width: 226,
            store: oActionSet.sceneStore,
            valueField: 'scene',
            displayField: 'name',
            triggerAction: 'all',
            selectOnFocus: true,
            editable: false
        });
        oActionSet.fieldSetAction.add(oActionSet.cbSceneSelector);
        
        oActionSet.rbAction2 = new Ext.form.Radio(
        {
            name: 'actionSelector_' + this.name + iIndex,
            boxLabel: "Ausgang setzen",
            width: 130
        });
        
        oActionSet.outputValue = new Ext.form.SliderField(
        {
            colspan: 3,
            disabled: true,
            width: 226
        });
        
        oActionSet.formatingFormPanel.add(oActionSet.rbAction2);
        oActionSet.fieldSetAction.add(oActionSet.outputValue);
        
        oActionSet.testButton = new Ext.Button(
        {
            text: "Testen",
            align: "right",
            width: 160
        });
        oActionSet.fieldSetAction.add(oActionSet.testButton);
        
        oActionSet.addButton = new Ext.Button(
        {
            iconCls: "addButton",
            align: "right"
        });
        oActionSet.fieldSetAction.add(oActionSet.addButton);
        
        oActionSet.addButton.on("click", function()
        {
            masterPanel.addSubAction();
            oActionSet.collapse(true);
        });
        
        oActionSet.removeButton = new Ext.Button(
        {
            iconCls: "deleteButton",
            align: "right"
        });
        oActionSet.fieldSetAction.add(oActionSet.removeButton);
        
        oActionSet.removeButton.on("click", function()
        {
            masterPanel.removeSubAction(oActionSet, masterPanel);
        });
        
        oActionSet.rbAction3 = new Ext.form.Radio(
        {
            name: 'actionSelector_' + this.name + iIndex,
            boxLabel: 'Blinken',
            colspan: 2,
            width: 130
        });
        oActionSet.formatingFormPanel.add(oActionSet.rbAction3);
        
        oActionSet.rbAction1.on('check', function(box, checked)
        {
            oActionSet.cbSceneSelector.setDisabled(!checked || (oActionSet.cbZoneSelector.getValue() == "") || oActionSet.cbGroupSelector.getValue() == "");
            masterPanel.setMyTitle(oActionSet);
        });
        oActionSet.rbAction2.on('check', function(box, checked)
        {
            oActionSet.outputValue.setDisabled(!checked);
            masterPanel.setMyTitle(oActionSet);
        });
        oActionSet.rbAction3.on('check', function(box, checked)
        {
            masterPanel.setMyTitle(oActionSet);
        });
        
        oActionSet.txtHLE.on('change', function()
        {
            masterPanel.setMyTitle(oActionSet);
        });
        oActionSet.outputValue.on('change', function()
        {
            masterPanel.setMyTitle(oActionSet);
        });
        
        oActionSet.cbSceneSelector.on('select', function()
        {
            masterPanel.setMyTitle(oActionSet);
        });
        oActionSet.cbDeviceSelector.on('select', function()
        {
            masterPanel.setMyTitle(oActionSet);
        });
        
        oActionSet.cbZoneSelector.on('select', function()
        {
            oActionSet.cbGroupSelector.setDisabled("" + this.getValue() == "0");
            oActionSet.cbGroupSelector.clearValue();
            oActionSet.groupName.proxy = new Ext.data.HttpProxy(
            {
                url: '/json/property/query?query=/apartment/zones/zone' + this.getValue() + '/groups/*(group,name)',
                method: 'GET'
            });
            oActionSet.groupName.load();
            masterPanel.setMyTitle(oActionSet);
        });
        
        oActionSet.cbGroupSelector.on('select', function()
        {
            oActionSet.cbSceneSelector.setDisabled(this.getValue() == null);
            oActionSet.cbSceneSelector.clearValue();
            oActionSet.sceneStore.proxy = new Ext.data.HttpProxy(
            {
                url: '/json/property/query?query=/apartment/zones/zone' + oActionSet.cbZoneSelector.getValue() +
                '/groups/group' +
                this.getValue() +
                '/scenes/*(scene,name)',
                method: 'GET'
            });
            oActionSet.sceneStore.load();
            masterPanel.setMyTitle(oActionSet);
        });
        
        oActionSet.rb1.on('check', function(box, checked)
        {
            oActionSet.cbZoneSelector.setDisabled(!checked);
            oActionSet.cbGroupSelector.setDisabled(!checked || (oActionSet.cbZoneSelector.getValue() == "0") || oActionSet.cbZoneSelector.getValue() == "");
            masterPanel.setMyTitle(oActionSet);
        });
        oActionSet.rb2.on('check', function(box, checked)
        {
            oActionSet.cbDeviceSelector.setDisabled(!checked);
        });
        oActionSet.rb3.on('check', function(box, checked)
        {
            oActionSet.txtHLE.setDisabled(!checked);
        });
        this.doLayout();
        
    },
    initComponent: function()
    {
    
        Configurator.ActionPanel.superclass.initComponent.apply(this);
        
        this.actionsSets = [];
        this.addSubAction();
    },
    setValue: function(sValue)
    {
        var sTempArray = sValue.split(";");
        var iCounter = 0;
        for (var iIndex = 0; iIndex < sTempArray.length; iIndex++) 
        {
            var sText = sTempArray[iIndex];
            if (sText != "") 
            {
                var oTemp = sText.split(":");
                if (this.actionsSets.length < (iCounter + 1)) 
                {
                    this.addSubAction();
                }
                var oActionSet = this.actionsSets[iCounter];
                if (oTemp[0] == "HLE") 
                {
                    oActionSet.rb3.setValue(true);
                    oActionSet.txtHLE.setValue(oTemp[1]);
                }
                else 
                {
                    if (oTemp[0] == "Device") 
                    {
                        oActionSet.rb2.setValue(true);
                        oActionSet.cbDeviceSelector.setValue(oTemp[1]);
                    }
                    if (oTemp[0] == "Zone") 
                    {
                        oActionSet.rb1.setValue(true);
                        oActionSet.cbZoneSelector.setValue(oTemp[1]);
                        oActionSet.cbGroupSelector.setValue(oTemp[3]);
                    }
                    if (oTemp[4] == "Scene") 
                    {
                        oActionSet.rbAction1.setValue(true);
                        oActionSet.cbSceneSelector.setValue(oTemp[5]);
                    }
                    if (oTemp[4] == "Output") 
                    {
                        oActionSet.rbAction2.setValue(true);
                        oActionSet.outputValue.setValue(oTemp[5]);
                    }
                    if (oTemp[4] == "Blink") 
                    {
                        oActionSet.rbAction3.setValue(true);
                    }
                }
                iCounter++;
            }
        }
    },
    getValue: function()
    {
        var sString = "";
        for (var i = 0; i < this.actionsSets.length; i++) 
        {
            var sTempString = "";
            var oActionSet = this.actionsSets[i];
            if (oActionSet.rb3.getValue()) 
            {
                if (oActionSet.txtHLE.getValue() != "") 
                    sString += "HLE:" + oActionSet.txtHLE.getValue() + ";";
            }
            else 
            {
                if (oActionSet.rb2.getValue()) 
                {
                    sTempString = "Device:" + oActionSet.cbDeviceSelector.getValue() + "::";
                }
                if (oActionSet.rb1.getValue()) 
                {
                    sTempString = "Zone:" + oActionSet.cbZoneSelector.getValue() + ":Group:" + oActionSet.cbGroupSelector.getValue();
                }
                
                if (sTempString != "") 
                {
                    if (oActionSet.rbAction1.getValue()) 
                        if (oActionSet.cbSceneSelector.getValue() != "") 
                        {
                            sString += sTempString + ":Scene:" + oActionSet.cbSceneSelector.getValue() + ";";
                        }
                    if (oActionSet.rbAction2.getValue()) 
                    {
                        sString += sTempString + ":Output:" + oActionSet.outputValue.getValue() + ";";
                    }
                    if (oActionSet.rbAction3.getValue()) 
                    {
                        sString += sTempString + ":Blink" + ";";
                    }
                }
            }
            
        }
        return sString;
    }
    
}); // end of extend
